==> FileConverter-1.01-20181019.031807-6-sources.jar: com/kdgcsoft/power/fileconverter/impl/Docx4jConverter.java <==
package com.kdgcsoft.power.fileconverter.impl;

import java.io.File;

import org.apache.commons.io.FileUtils;

import com.kdgcsoft.power.fileconverter.FileConverterSettings;
import com.kdgcsoft.power.fileconverter.IFileConverter;

/**
 * 把Docx转换成pdf，基于docx4j。
 * 转换效果一般，仅供测试。在能够使用jod或jacob的情况下，不推荐使用。
 * 
 * @author hling
 *
 */
public class Docx4jConverter implements IFileConverter {

	@Override
	public File convert(final File srcFile, final File destFile, final FileConverterSettings settings) throws Exception {
		 FileUtils.touch(destFile);
		 docx2pdf(srcFile, destFile);
		 return  destFile;
	}

	public static void docx2pdf(final File srcFile, final File destFile) throws Exception {
//		WordprocessingMLPackage wordMLPackage = WordprocessingMLPackage.load(srcFile);
//		Mapper fontMapper = new IdentityPlusMapper();
//		wordMLPackage.setFontMapper(fontMapper);
//		fontMapper.put("隶书", PhysicalFonts.get("LiSu"));
//		fontMapper.put("宋体", PhysicalFonts.get("SimSun"));
//		fontMapper.put("微软雅黑", PhysicalFonts.get("Microsoft Yahei"));
//		fontMapper.put("黑体", PhysicalFonts.get("SimHei"));
//		fontMapper.put("楷体", PhysicalFonts.get("KaiTi"));
//		fontMapper.put("新宋体", PhysicalFonts.get("NSimSun"));
//		fontMapper.put("华文行楷", PhysicalFonts.get("STXingkai"));
//		fontMapper.put("华文仿宋", PhysicalFonts.get("STFangsong"));
//		fontMapper.put("宋体扩展", PhysicalFonts.get("simsun-extB"));
//		fontMapper.put("仿宋", PhysicalFonts.get("FangSong"));
//		fontMapper.put("仿宋_GB2312", PhysicalFonts.get("FangSong_GB2312"));
//		fontMapper.put("幼圆", PhysicalFonts.get("YouYuan"));
//		fontMapper.put("华文宋体", PhysicalFonts.get("STSong"));
//		fontMapper.put("华文中宋", PhysicalFonts.get("STZhongsong"));
//		fontMapper.put("方正小标宋_GBK", PhysicalFonts.get("SimSun"));
//		
//		OutputStream os = new FileOutputStream(destFile);
//		FOSettings foSettings = Docx4J.createFOSettings();
//		foSettings.setWmlPackage(wordMLPackage);
//		Docx4J.toFO(foSettings, os, Docx4J.FLAG_EXPORT_PREFER_XSL);
//		os.close();
	}

}

==> FileConverter-1.4-20200717.043215-7-sources.jar: com/kdgcsoft/power/fileconverter/impl/Docx4jConverter.java <==
package com.kdgcsoft.power.fileconverter.impl;

import java.io.File;

import org.apache.commons.io.FileUtils;

import com.kdgcsoft.power.fileconverter.FileConverterSettings;
import com.kdgcsoft.power.fileconverter.IFileConverter;

/**
 * 把Docx转换成pdf，基于docx4j。
 * 转换效果一般，仅供测试。在能够使用jod或jacob的情况下，不推荐使用。
 * 
 * @author hling
 *
 */
public class Docx4jConverter implements IFileConverter {

	@Override
	public File convert(final File srcFile, final File destFile, final FileConverterSettings settings) throws Exception {
		 FileUtils.touch(destFile);
		 docx2pdf(srcFile, destFile);
		 return  destFile;
	}

	public static void docx2pdf(final File srcFile, final File destFile) {
//		WordprocessingMLPackage wordMLPackage = WordprocessingMLPackage.load(srcFile);
//		Mapper fontMapper = new IdentityPlusMapper();
//		wordMLPackage.setFontMapper(fontMapper);
//		fontMapper.put("隶书", PhysicalFonts.get("LiSu"));
//		fontMapper.put("宋体", PhysicalFonts.get("SimSun"));
//		fontMapper.put("微软雅黑", PhysicalFonts.get("Microsoft Yahei"));
//		fontMapper.put("黑体", PhysicalFonts.get("SimHei"));
//		fontMapper.put("楷体", PhysicalFonts.get("KaiTi"));
//		fontMapper.put("新宋体", PhysicalFonts.get("NSimSun"));
//		fontMapper.put("华文行楷", PhysicalFonts.get("STXingkai"));
//		fontMapper.put("华文仿宋", PhysicalFonts.get("STFangsong"));
//		fontMapper.put("宋体扩展", PhysicalFonts.get("simsun-extB"));
//		fontMapper.put("仿宋", PhysicalFonts.get("FangSong"));
//		fontMapper.put("仿宋_GB2312", PhysicalFonts.get("FangSong_GB2312"));
//		fontMapper.put("幼圆", PhysicalFonts.get("YouYuan"));
//		fontMapper.put("华文宋体", PhysicalFonts.get("STSong"));
//		fontMapper.put("华文中宋", PhysicalFonts.get("STZhongsong"));
//		fontMapper.put("方正小标宋_GBK", PhysicalFonts.get("SimSun"));
//		
//		OutputStream os = new FileOutputStream(destFile);
//		FOSettings foSettings = Docx4J.createFOSettings();
//		foSettings.setWmlPackage(wordMLPackage);
//		Docx4J.toFO(foSettings, os, Docx4J.FLAG_EXPORT_PREFER_XSL);
//		os.close();
	}

}
